@@ -1,13 +1,57 @@
 #include "commongc_internal.h"
 #include "gc2_obj.h"
 
-#if defined(MZ_USE_PLACES)
-/*
-# define GC_DEBUG_PAGES
-# define MASTER_ALLOC_DEBUG
-# define KILLING_DEBUG
-*/
-#endif
+/* the page type constants */
+enum {
+  PAGE_TAGGED   = 0,
+  PAGE_ATOMIC   = 1,
+  PAGE_ARRAY    = 2,
+  PAGE_PAIR     = 3,
+  PAGE_BIG      = 4,
+  /* the number of page types in then gen1 array: */
+  PAGE_TYPES    = 5,
+  /* medium page types: */
+  PAGE_MED_ATOMIC = 6,
+  PAGE_MED_NONATOMIC = 7
+};
+
+enum {
+  MED_PAGE_NONATOMIC_INDEX   = 0,
+  MED_PAGE_ATOMIC_INDEX      = 1,
+  /* the number of medium-page types in the array: */
+  MED_PAGE_TYPES       = 2
+};
+
+enum {
+  SIZE_CLASS_SMALL_PAGE      = 0, /* can be a nursery page */
+  SIZE_CLASS_MED_PAGE        = 1,
+  SIZE_CLASS_BIG_PAGE        = 2,
+  SIZE_CLASS_BIG_PAGE_MARKED = 3
+};
+
+enum {
+  MMU_ZEROED = 0,
+  MMU_DIRTY  = 1,
+};
+
+enum {
+  MMU_SMALL_GEN1   = 0,
+  MMU_BIG_MED      = 1,
+  MMU_SMALL_GEN0   = 1,
+};
+
+enum {
+  MMU_NON_PROTECTABLE   = 0,
+  MMU_PROTECTABLE       = 1,
+};
+
+enum {
+  AGE_GEN_0    = 0,
+  AGE_GEN_HALF = 1,
+  AGE_GEN_1    = 2,
+  AGE_VACATED  = 3, /* used for pages to be removed */
+  AGE_GEN_INC  = 4  /* used for naming a finalizer set */
+};
 
 typedef struct mpage {
   struct mpage *next;
@@ -15,6 +59,7 @@ typedef struct mpage {
   void *addr;
   void *mmu_src_block;
   struct mpage *modified_next; /* next in chain of pages for backpointers, marks, etc. */
+  struct mpage *inc_modified_next; /* like modified_next, but for incrementally marked pages */
   struct mpage *reprotect_next; /* next in a chain of pages that need to be re-protected */
 #ifdef MZ_GC_BACKTRACE
   void **backtrace;
@@ -35,8 +80,8 @@ typedef struct mpage {
     uintptr_t alloc_size; /* for a nursery: total size of the nursery */
     uintptr_t med_search_start; /* medium page: offset for searching for a free slot */
     uintptr_t scan_boundary; /* small gen1 page: during GC, boundary between objects that can be
-                                left alone and that that will be scanned & fixed up; objects before
-                                have cleared "mark" bits, while objects after (may) have "mark" bits sets */
+                                should be treated as previously gen1 and objects that should be
+                                treated as just moved from gen0 */
   };
   unsigned short live_size; /* except for big pages, total size of live objects on the page */
   unsigned char generation    :2;
@@ -44,9 +89,12 @@ typedef struct mpage {
   unsigned char size_class    :2;
   unsigned char page_type     :3; 
   unsigned char marked_on     :1;
+  unsigned char inc_marked_on :1;
   unsigned char marked_from   :1;
   unsigned char has_new       :1;
   unsigned char mprotected    :1;
+  unsigned char reprotect     :1; /* in reprotect_next chain already */
+  unsigned char non_dead_as_mark :1; /* already repaired in incremental pass */
 } mpage;
 
 typedef struct Gen0 {
@@ -82,6 +130,11 @@ typedef struct MarkSegment {
   void **top;
 } MarkSegment;
 
+typedef struct Inc_Admin_Page {
+  struct Inc_Admin_Page *next;
+  size_t size, pos;
+} Inc_Admin_Page;
+
 typedef struct GC_Thread_Info {
   void *thread;
   int owner;
@@ -140,9 +193,19 @@ typedef mpage **PageMap;
 
 #define NUM_MED_PAGE_SIZES (((LOG_APAGE_SIZE - 1) - 3) + 1)
 
+enum {
+  FNL_LEVEL_GEN_0,
+  FNL_LEVEL_GEN_1,
+  FNL_LEVEL_INC_1,
+  FNL_LEVEL_INC_2,
+  FNL_LEVEL_INC_3,
+  NUM_FNL_LEVELS
+};
+
 typedef struct NewGC {
   Gen0 gen0;
   Gen_Half gen_half;
+  int number_of_tags;
   Mark2_Proc  *mark_table;   /* the table of mark procs */
   Fixup2_Proc *fixup_table;  /* the table of repair procs */
   PageMap page_maps;
@@ -158,15 +221,19 @@ typedef struct NewGC {
   /* linked list of pages with back pointers to be traversed in a
      minor collection, etc.: */
   struct mpage *modified_next;
+  /* pages marked incrementally: */
+  struct mpage *inc_modified_next;
+  /* tail of inc_modified_next being repaired incrementally */
+  struct mpage *inc_repair_next;
   /* linked list of pages that need to be given write protection at
      the end of the GC cycle: */
   struct mpage *reprotect_next;
 
-  MarkSegment *mark_stack;
+  MarkSegment *mark_stack, *inc_mark_stack, *acct_mark_stack;
 
   /* Finalization */
-  Fnl *run_queue;
-  Fnl *last_in_queue;
+  Fnl *run_queue, *last_in_queue;
+  Fnl *inc_run_queue, *inc_last_in_queue;
 
   int mark_depth;
 
@@ -189,18 +256,32 @@ typedef struct NewGC {
   int avoid_collection;
 
   unsigned char generations_available        :1;
+  unsigned char started_incremental          :1; /* must stick with incremental until major GC */
+  unsigned char all_marked_incremental       :1; /* finished all marking for an incremental GC */
+  unsigned char finished_incremental         :1; /* finished marking and reparing an incremental GC */
+  unsigned char accounted_incremental        :1; /* memory accounting for an incremental GC */
   unsigned char in_unsafe_allocation_mode    :1;
-  unsigned char full_needed_for_finalization :1;
+  unsigned char full_needed_again            :1;
   unsigned char no_further_modifications     :1;
   unsigned char gc_full                      :1; /* a flag saying if this is a full/major collection */
+  unsigned char had_finished_incremental     :1; /* when gc_full, indicates full GC after incremental finished */
   unsigned char use_gen_half                 :1;
   unsigned char running_finalizers           :1;
   unsigned char back_pointers                :1;
   unsigned char need_fixup                   :1;
+  unsigned char check_gen1                   :1; /* check marks bit for old generation (instead of claiming always marked) */
+  unsigned char mark_gen1                    :1; /* set mark bits for old generation */
+  unsigned char inc_gen1                     :1; /* during incremental marking of old generation */
+  unsigned char fnl_gen1                     :1; /* during incremental finalization of old generation */
+  unsigned char during_backpointer           :1;
+  unsigned char incremental_requested        :4; /* counts down to track recentness of request */
+  unsigned char high_fragmentation           :1;
+  unsigned char unprotected_page             :1;
 
   /* blame the child */
   unsigned int doing_memory_accounting        :1;
   unsigned int really_doing_accounting        :1;
+  unsigned int next_really_doing_accounting   :1;
   unsigned int old_btc_mark                   :1;
   unsigned int new_btc_mark                   :1;
   unsigned int reset_limits                   :1;
@@ -216,6 +297,11 @@ typedef struct NewGC {
   unsigned int since_last_full;
   uintptr_t last_full_mem_use;
 
+  uintptr_t prop_count;
+  uintptr_t inc_prop_count;
+  uintptr_t copy_count;     /* bytes */
+  uintptr_t traverse_count; /* words */
+
   /* These collect information about memory usage, for use in GC_dump. */
   uintptr_t peak_memory_use;
   uintptr_t peak_pre_memory_use;
@@ -227,7 +313,6 @@ typedef struct NewGC {
   uintptr_t modified_unprotects;
   
   /* THREAD_LOCAL variables that need to be saved off */
-  MarkSegment  *saved_mark_stack;
   void         *saved_GC_variable_stack;
   uintptr_t saved_GC_gen0_alloc_page_ptr;
   uintptr_t saved_GC_gen0_alloc_page_end;
@@ -238,7 +323,9 @@ typedef struct NewGC {
   int           dont_master_gc_until_child_registers;   /* :1: */
 #endif
 
- struct mpage *thread_local_pages;
+  Inc_Admin_Page *inc_space;
+  
+  struct mpage *thread_local_pages;
 
   /* Callbacks */
   void (*GC_collect_start_callback)(void);
@@ -246,18 +333,19 @@ typedef struct NewGC {
   GC_collect_inform_callback_Proc GC_collect_inform_callback;
   uintptr_t (*GC_get_thread_stack_base)(void);
   GC_Post_Propagate_Hook_Proc GC_post_propagate_hook;
+  GC_Treat_As_Incremental_Mark_Proc treat_as_incremental_mark_hook;
+  short treat_as_incremental_mark_tag;
 
   GC_Immobile_Box *immobile_boxes;
 
-  Fnl *finalizers;
-  Fnl *splayed_finalizers;
-  Fnl *gen0_finalizers;
-  Fnl *splayed_gen0_finalizers;
+  Fnl *finalizers[NUM_FNL_LEVELS];
+  Fnl *splayed_finalizers[NUM_FNL_LEVELS];
   int num_fnls;
 
   void *park[2];
   void *park_fsave[2];
   void *park_isave[2];
+# define CHECK_PARK_UNUSED(gc) GC_ASSERT(!gc->park[0])
 
   unsigned short weak_array_tag;
   unsigned short weak_box_tag;
@@ -265,16 +353,30 @@ typedef struct NewGC {
   unsigned short cust_box_tag;
   unsigned short phantom_tag;
 
-  uintptr_t phantom_count;
-  uintptr_t gen0_phantom_count;
+  uintptr_t phantom_count; /* old-generation count; included in `memory_in_use`, except during a minor collection */
+  uintptr_t gen0_phantom_count; /* count for generation 0 + 1/2 */
+  uintptr_t inc_phantom_count; /* accumulated count for an incremental collection */
+  uintptr_t acct_phantom_count; /* count that is set during memory accounting */
 
-  Roots roots;
-  GC_Weak_Array *weak_arrays;
-  GC_Weak_Box   *weak_boxes[2];
-  GC_Ephemeron  *ephemerons;
-  int num_last_seen_ephemerons;
+  Roots roots;  
   struct MMU     *mmu;
 
+  /* The `inc_` variants hold old-generation objects discovered in
+     incremental mode. If incremental mode is started, the plain
+     variants for a minor collection need to be added to the `inc_`
+     variants, since promoted objects from the nursery keep their mark
+     bits. The `bp_` variants are old-generation objects that were
+     marked as (potentially) containing backpointers; they are treated
+     like the normal ones, but not added to `inc_` because they're
+     either already marked or should be added when they're later
+     marked. */
+  GC_Weak_Array *weak_arrays, *inc_weak_arrays, *bp_weak_arrays;
+  GC_Weak_Box   *weak_boxes[2], *inc_weak_boxes[2], *bp_weak_boxes[2];
+  GC_Ephemeron  *ephemerons, *inc_ephemerons, *bp_ephemerons;
+  int num_last_seen_ephemerons;
+
+  void *weak_incremental_done;
+
   Allocator *saved_allocator;
 
 #ifdef MZ_USE_PLACES
