@@ -158,11 +158,11 @@ branch_rec {
 
 unclosed_proc {
  mark:
-  Scheme_Closure_Data *d = (Scheme_Closure_Data *)p;
+  Scheme_Lambda *d = (Scheme_Lambda *)p;
 
   gcMARK2(d->name, gc);
-  gcMARK2(d->code, gc);
-  gcMARK2(d->closure_map, gc);
+  gcMARK2(d->body, gc);
+  gcMARK2(d->closure_map, gc); /* covers `ir_info` */
   gcMARK2(d->tl_map, gc);
 #ifdef MZ_USE_JIT
   gcMARK2(d->u.native_code, gc);
@@ -170,7 +170,7 @@ unclosed_proc {
 #endif
 
  size:
-  gcBYTES_TO_WORDS(sizeof(Scheme_Closure_Data));
+  gcBYTES_TO_WORDS(sizeof(Scheme_Lambda));
 }
 
 let_value {
@@ -228,27 +228,50 @@ with_cont_mark {
   gcBYTES_TO_WORDS(sizeof(Scheme_With_Continuation_Mark));
 }
 
-comp_let_value {
+ir_local {
  mark:
-  Scheme_Compiled_Let_Value *c = (Scheme_Compiled_Let_Value *)p;
+  Scheme_IR_Local *var = (Scheme_IR_Local *)p;
 
-  gcMARK2(c->flags, gc);
-  gcMARK2(c->value, gc);
-  gcMARK2(c->body, gc);
-  gcMARK2(c->names, gc);
+  gcMARK2(var->name, gc);
+  switch (var->mode) {
+  case SCHEME_VAR_MODE_LETREC_CHECK:
+    gcMARK2(var->letrec_check.frame, gc);
+    break;
+  case SCHEME_VAR_MODE_OPTIMIZE:
+    gcMARK2(var->optimize.known_val, gc);
+    gcMARK2(var->optimize.transitive_uses, gc);
+    break;
+  case SCHEME_VAR_MODE_RESOLVE:
+    gcMARK2(var->resolve.lifted, gc);
+    break;
+  default:
+    break;
+  }
 
  size:
-  gcBYTES_TO_WORDS(sizeof(Scheme_Compiled_Let_Value));
+  gcBYTES_TO_WORDS(sizeof(Scheme_IR_Local));
+}
+
+ir_let_value {
+ mark:
+  Scheme_IR_Let_Value *c = (Scheme_IR_Let_Value *)p;
+
+  gcMARK2(c->value, gc);
+  gcMARK2(c->body, gc);
+  gcMARK2(c->vars, gc);
+
+ size:
+  gcBYTES_TO_WORDS(sizeof(Scheme_IR_Let_Value));
 }
 
 let_header {
  mark:
-  Scheme_Let_Header *h = (Scheme_Let_Header *)p;
+  Scheme_IR_Let_Header *h = (Scheme_IR_Let_Header *)p;
   
   gcMARK2(h->body, gc);
 
  size:
-  gcBYTES_TO_WORDS(sizeof(Scheme_Let_Header));
+  gcBYTES_TO_WORDS(sizeof(Scheme_IR_Let_Header));
 }
 
 set_bang {
@@ -308,14 +331,14 @@ closed_prim_proc {
 scm_closure {
   Scheme_Closure *c = (Scheme_Closure *)p;
   int closure_size = (c->code 
-                      ? ((Scheme_Closure_Data *)GC_resolve2(c->code, gc))->closure_size
+                      ? ((Scheme_Lambda *)GC_resolve2(c->code, gc))->closure_size
                       : 0);
 
  mark:
 
   int i = closure_size;
   START_MARK_ONLY;
-# define CLOSURE_DATA_TYPE Scheme_Closure_Data
+# define CLOSURE_DATA_TYPE Scheme_Lambda
 # include "mzclpf_decl.inc"
   END_MARK_ONLY;
 
@@ -1092,6 +1115,7 @@ module_val {
   gcMARK2(m->hints, gc);
   gcMARK2(m->ii_src, gc);
   gcMARK2(m->super_bxs_info, gc);
+  gcMARK2(m->sub_iidx_ptrs, gc);
 
   gcMARK2(m->comp_prefix, gc);
   gcMARK2(m->prefix, gc);
@@ -1268,6 +1292,7 @@ mark_comp_env {
   gcMARK2(e->bindings, gc);
   gcMARK2(e->vals, gc);
   gcMARK2(e->shadower_deltas, gc);
+  gcMARK2(e->vars, gc);
   gcMARK2(e->dup_check, gc);
   gcMARK2(e->intdef_name, gc);
   gcMARK2(e->in_modidx, gc);
@@ -1298,12 +1323,8 @@ mark_resolve_info {
   gcMARK2(i->prefix, gc);
   gcMARK2(i->stx_map, gc);
   gcMARK2(i->tl_map, gc);
-  gcMARK2(i->old_pos, gc);
-  gcMARK2(i->new_pos, gc);
-  gcMARK2(i->old_stx_pos, gc);
-  gcMARK2(i->flags, gc);
+  gcMARK2(i->redirects, gc);
   gcMARK2(i->lifts, gc);
-  gcMARK2(i->lifted, gc);
   gcMARK2(i->next, gc);
 
  size:
@@ -1314,16 +1335,19 @@ mark_unresolve_info {
  mark:
   Unresolve_Info *i = (Unresolve_Info *)p;
   
-  gcMARK2(i->flags, gc);
-  gcMARK2(i->depths, gc);
+  gcMARK2(i->vars, gc);
   gcMARK2(i->prefix, gc);
   gcMARK2(i->closures, gc);
-  gcMARK2(i->closures, gc);
   gcMARK2(i->module, gc);
   gcMARK2(i->comp_prefix, gc);
+  gcMARK2(i->new_toplevels, gc);
+  gcMARK2(i->from_modidx, gc);
+  gcMARK2(i->to_modidx, gc);
+  gcMARK2(i->opt_env, gc);
+  gcMARK2(i->opt_insp, gc);
+  gcMARK2(i->inline_variants, gc);
   gcMARK2(i->toplevels, gc);
   gcMARK2(i->definitions, gc);
-  gcMARK2(i->ref_args, gc);
   gcMARK2(i->ref_lifts, gc);
 
  size:
@@ -1361,7 +1385,6 @@ mark_letrec_check_frame {
   gcMARK2(frame->def, gc);
   gcMARK2(frame->next, gc);
   gcMARK2(frame->ref, gc);
-  gcMARK2(frame->head, gc);
   gcMARK2(frame->deferred_chain, gc);
 
  size:
@@ -1390,18 +1413,17 @@ mark_optimize_info {
  mark:
   Optimize_Info *i = (Optimize_Info *)p;
   
-  gcMARK2(i->stat_dists, gc);
-  gcMARK2(i->sd_depths, gc);
   gcMARK2(i->next, gc);
-  gcMARK2(i->use, gc);
   gcMARK2(i->consts, gc);
   gcMARK2(i->cp, gc);
+  gcMARK2(i->env, gc);
+  gcMARK2(i->insp, gc);
   gcMARK2(i->top_level_consts, gc);
-  gcMARK2(i->transitive_use, gc);
-  gcMARK2(i->transitive_use_len, gc);
+  gcMARK2(i->transitive_use_var, gc);
   gcMARK2(i->context, gc);
   gcMARK2(i->logger, gc);
   gcMARK2(i->types, gc);
+  gcMARK2(i->uses, gc);
 
  size:
   gcBYTES_TO_WORDS(sizeof(Optimize_Info));
@@ -1411,8 +1433,7 @@ mark_once_used {
  mark:
   Scheme_Once_Used *o = (Scheme_Once_Used *)p;
   gcMARK2(o->expr, gc);
-  gcMARK2(o->info, gc);
-  gcMARK2(o->next, gc);
+  gcMARK2(o->var, gc);
  size:
   gcBYTES_TO_WORDS(sizeof(Scheme_Once_Used));
 }
@@ -1457,18 +1478,6 @@ END validate;
 
 START fun;
 
-mark_closure_info {
- mark:
-  Closure_Info *i = (Closure_Info *)p;
-  
-  gcMARK2(i->local_flags, gc);
-  gcMARK2(i->base_closure_map, gc);
-  gcMARK2(i->local_type_map, gc);
-
- size:
-  gcBYTES_TO_WORDS(sizeof(Closure_Info));
-}
-
 mark_dyn_wind_cell {
  mark:
   Scheme_Dynamic_Wind_List *l = (Scheme_Dynamic_Wind_List *)p;
@@ -2254,6 +2263,19 @@ END struct;
 
 START compile;
 
+mark_ir_lambda_info {
+ mark:
+  Scheme_IR_Lambda_Info *i = (Scheme_IR_Lambda_Info *)p;
+  
+  gcMARK2(i->base_closure, gc);
+  gcMARK2(i->vars, gc);
+  gcMARK2(i->arg_types, gc);
+  gcMARK2(i->arg_type_contributors, gc);
+
+ size:
+  gcBYTES_TO_WORDS(sizeof(Scheme_IR_Lambda_Info));
+}
+
 END compile;
 
 /**********************************************************************/
@@ -2274,6 +2296,7 @@ mark_cport {
   gcMARK2(cp->ht, gc);
   gcMARK2(cp->ut, gc);
   gcMARK2(cp->symtab, gc);
+  gcMARK2(cp->symtab_entries, gc);
   gcMARK2(cp->relto, gc);
   gcMARK2(cp->magic_sym, gc);
   gcMARK2(cp->magic_val, gc);
@@ -2312,6 +2335,7 @@ mark_delay_load {
   Scheme_Load_Delay *ld = (Scheme_Load_Delay *)p;
   gcMARK2(ld->path, gc);
   gcMARK2(ld->symtab, gc);
+  gcMARK2(ld->symtab_entries, gc);
   gcMARK2(ld->shared_offsets, gc);
   gcMARK2(ld->relto, gc);
   gcMARK2(ld->ut, gc);
@@ -2448,7 +2472,7 @@ START jit;
 
 native_closure {
   Scheme_Native_Closure *c = (Scheme_Native_Closure *)p;
-  int closure_size = ((Scheme_Native_Closure_Data *)GC_resolve2(c->code, gc))->closure_size;
+  int closure_size = ((Scheme_Native_Lambda *)GC_resolve2(c->code, gc))->closure_size;
 
   if (closure_size < 0) {
     closure_size = -(closure_size + 1);
@@ -2458,7 +2482,7 @@ native_closure {
   {
   int i = closure_size;
   START_MARK_ONLY;
-# define CLOSURE_DATA_TYPE Scheme_Native_Closure_Data
+# define CLOSURE_DATA_TYPE Scheme_Native_Lambda
 # include "mzclpf_decl.inc"
   END_MARK_ONLY;
 
@@ -2486,7 +2510,7 @@ mark_jit_state {
  mark:
   mz_jit_state *j = (mz_jit_state *)p;
   gcMARK2(j->mappings, gc);
-  gcMARK2(j->self_data, gc);
+  gcMARK2(j->self_lam, gc);
   gcMARK2(j->example_argv, gc);
   gcMARK2(j->nc, gc);
   gcMARK2(j->retaining_data, gc);
@@ -2498,7 +2522,7 @@ mark_jit_state {
 
 native_unclosed_proc {
  mark:
-  Scheme_Native_Closure_Data *d = (Scheme_Native_Closure_Data *)p;
+  Scheme_Native_Lambda *d = (Scheme_Native_Lambda *)p;
   int i;
 
   gcMARK2(d->u2.name, gc);
@@ -2511,20 +2535,21 @@ native_unclosed_proc {
     gcMARK2(d->u.arities, gc);
   }
   gcMARK2(d->tl_map, gc);
+  gcMARK2(d->eq_key, gc);
 
  size:
-  gcBYTES_TO_WORDS(sizeof(Scheme_Native_Closure_Data));
+  gcBYTES_TO_WORDS(sizeof(Scheme_Native_Lambda));
 }
 
 native_unclosed_proc_plus_case {
  mark:
-  Scheme_Native_Closure_Data_Plus_Case *d = (Scheme_Native_Closure_Data_Plus_Case *)p;
+  Scheme_Native_Lambda_Plus_Case *d = (Scheme_Native_Lambda_Plus_Case *)p;
 
   native_unclosed_proc_MARK(p, gc);
   gcMARK2(d->case_lam, gc);
 
  size:
-  gcBYTES_TO_WORDS(sizeof(Scheme_Native_Closure_Data_Plus_Case));
+  gcBYTES_TO_WORDS(sizeof(Scheme_Native_Lambda_Plus_Case));
 }
 
 END jit;
