@@ -1,6 +1,6 @@
 /*
   Racket
-  Copyright (c) 2004-2015 PLT Design Inc.
+  Copyright (c) 2004-2016 PLT Design Inc.
   Copyright (c) 1995-2001 Matthew Flatt
 
     This library is free software; you can redistribute it and/or
@@ -1658,6 +1658,13 @@ void scheme_enable_garbage_collection(int on)
 #endif
 }
 
+void scheme_incremental_garbage_collection(int on)
+{
+#ifdef MZ_PRECISE_GC
+  GC_set_incremental_mode(on);
+#endif
+}
+
 MZ_DO_NOT_INLINE(uintptr_t scheme_get_deeper_address(void));
 
 uintptr_t scheme_get_deeper_address(void)
@@ -2016,7 +2023,7 @@ static void print_tagged_value(const char *prefix,
   scheme_check_print_is_obj = check_home;
 
   {
-    if (SCHEME_TYPE(v) > _scheme_compiled_values_types_) {
+    if (SCHEME_TYPE(v) > _scheme_ir_values_types_) {
       sprintf(hashstr, "{%" PRIdPTR "}", scheme_hash_key(v));
       hash_code = hashstr;
     }
@@ -2906,16 +2913,16 @@ intptr_t scheme_count_memory(Scheme_Object *root, Scheme_Hash_Table *ht)
 #endif
     }
     break;
-  case scheme_unclosed_procedure_type:
-  case scheme_compiled_unclosed_procedure_type:
+  case scheme_lambda_type:
+  case scheme_ir_lambda_type:
     {
-      Scheme_Closure_Data *data = 
-	(Scheme_Closure_Data *)root;
+      Scheme_Lambda *data = 
+	(Scheme_Lambda *)root;
 
-      s = sizeof(Scheme_Closure_Data);
+      s = sizeof(Scheme_Lambda);
       s += data->closure_size * sizeof(mzshort);
 #if FORCE_KNOWN_SUBPARTS
-      e = COUNT(data->code);
+      e = COUNT(data->body);
 #endif
     }
     break;
@@ -2929,11 +2936,11 @@ intptr_t scheme_count_memory(Scheme_Object *root, Scheme_Hash_Table *ht)
 #endif
     }
     break;
-  case scheme_compiled_let_value_type:
+  case scheme_ir_let_value_type:
     {
-      Scheme_Compiled_Let_Value *let = (Scheme_Compiled_Let_Value *)root;
+      Scheme_IR_Let_Value *let = (Scheme_IR_Let_Value *)root;
 
-      s = sizeof(Scheme_Compiled_Let_Value);
+      s = sizeof(Scheme_IR_Let_Value);
 #if FORCE_KNOWN_SUBPARTS
       e = COUNT(let->value) + COUNT(let->body);
 #endif
@@ -2949,11 +2956,11 @@ intptr_t scheme_count_memory(Scheme_Object *root, Scheme_Hash_Table *ht)
 #endif
     }
     break;
-  case scheme_compiled_let_void_type:
+  case scheme_ir_let_header_type:
     {
-      Scheme_Let_Header *let = (Scheme_Let_Header *)root;
+      Scheme_IR_Let_Header *let = (Scheme_IR_Let_Header *)root;
 
-      s = sizeof(Scheme_Let_Header);
+      s = sizeof(Scheme_IR_Let_Header);
 #if FORCE_KNOWN_SUBPARTS
       e = COUNT(let->body);
 #endif
@@ -3033,11 +3040,11 @@ intptr_t scheme_count_memory(Scheme_Object *root, Scheme_Hash_Table *ht)
     break;
   case scheme_closure_type:
     {
-      Scheme_Closure_Data *data;
+      Scheme_Lambda *data;
       Scheme_Object **vals;
       
-      data = SCHEME_COMPILED_CLOS_CODE(root);
-      vals = SCHEME_COMPILED_CLOS_ENV(root);
+      data = SCHEME_CLOSURE_CODE(root);
+      vals = SCHEME_CLOSURE_ENV(root);
 
       s += (data->closure_size * sizeof(Scheme_Object *));
 #if FORCE_KNOWN_SUBPARTS
@@ -3078,8 +3085,6 @@ intptr_t scheme_count_memory(Scheme_Object *root, Scheme_Hash_Table *ht)
   case scheme_undefined_type:
     /* Only one */
     break;
-  case scheme_syntax_compiler_type:
-    break;
   case scheme_macro_type:
   case scheme_set_macro_type:
     s = sizeof(Scheme_Small_Object);
